import type { TextDocument } from 'vscode-languageserver-textdocument';
import type * as vscode from 'vscode-languageserver';
export interface Range {
    start: number;
    end: number;
}
export declare enum Mode {
    /**
     * @case1
     * 123456 -> abcdef
     * ^    ^    ^    ^
     * @case2
     * 123456 -> abcdef
     *  ^  ^      ^  ^
     * @case3
     * 123456 -> abcdef
     *   ^^        ^^
     */
    Offset = 0,
    /**
     * @case1
     * 123456 -> abcdef
     * ^    ^    ^    ^
     * @case2
     * 123456 -> abcdef
     *  ^  ^     NOT_MATCH
     * @case3
     * 123456 -> abcdef
     *   ^^      NOT_MATCH
     */
    Totally = 1,
    /**
     * @case1
     * 123456 -> abcdef
     * ^    ^    ^    ^
     * @case2
     * 123456 -> abcdef
     *  ^  ^     ^    ^
     * @case3
     * 123456 -> abcdef
     *   ^^      ^    ^
     */
    Expand = 2,
    /**
     * @case1
     * 123456 -> abcdef
     * ^     ^   ^    ^
     * @case2
     * 123456 -> abcdef
     *      ^^   ^    ^
     * @case3
     * 123456 -> abcdef
     *       ^^  NOT_MATCH
     */
    Overlap = 3
}
export declare type MappingBase = {
    mode: Mode;
    sourceRange: Range;
    mappedRange: Range;
};
export declare type Mapping<T> = MappingBase & {
    data: T;
    additional?: MappingBase[];
};
export declare class SourceMapBase<Data = undefined> {
    mappings: Mapping<Data>[];
    constructor(_mappings?: Mapping<Data>[]);
    private cache;
    getSourceRange(start: number, end?: number): {
        data: Data;
        start: number;
        end: number;
    } | undefined;
    getMappedRange(start: number, end?: number): {
        data: Data;
        start: number;
        end: number;
    } | undefined;
    getSourceRanges(start: number, end?: number): Generator<{
        data: Data;
        start: number;
        end: number;
    }, void, unknown>;
    getMappedRanges(start: number, end?: number): Generator<{
        data: Data;
        start: number;
        end: number;
    }, void, unknown>;
    protected getRanges(startOffset: number, endOffset: number, sourceToTarget: boolean): Generator<{
        data: Data;
        start: number;
        end: number;
    }, void, unknown>;
    private getRange;
}
export declare class SourceMap<Data = undefined> extends SourceMapBase<Data> {
    sourceDocument: TextDocument;
    mappedDocument: TextDocument;
    _mappings?: Mapping<Data>[] | undefined;
    constructor(sourceDocument: TextDocument, mappedDocument: TextDocument, _mappings?: Mapping<Data>[] | undefined);
    getSourceRange<T extends number | vscode.Position>(start: T, end?: T): {
        data: Data;
        start: T;
        end: T;
    } | undefined;
    getMappedRange<T extends number | vscode.Position>(start: T, end?: T): {
        data: Data;
        start: T;
        end: T;
    } | undefined;
    getSourceRanges<T extends number | vscode.Position>(start: T, end?: T): Generator<{
        data: Data;
        start: T;
        end: T;
    }, void, unknown>;
    getMappedRanges<T extends number | vscode.Position>(start: T, end?: T): Generator<{
        data: Data;
        start: T;
        end: T;
    }, void, unknown>;
    protected getRanges<T extends number | vscode.Position>(start: T, end: T, sourceToTarget: boolean): Generator<{
        data: Data;
        start: T;
        end: T;
    }, void, unknown>;
}
